.. -*- mode: rst -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:

.. _chap_cmdline:

**********************
Command line reference
**********************

Main command
============

.. toctree::
   :maxdepth: 1

   generated/man/datalad

Dataset operations
==================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-add
   generated/man/datalad-create
   generated/man/datalad-create-sibling
   generated/man/datalad-create-sibling-github
   generated/man/datalad-drop
   generated/man/datalad-get
   generated/man/datalad-install
   generated/man/datalad-publish
   generated/man/datalad-remove
   generated/man/datalad-save
   generated/man/datalad-update
   generated/man/datalad-uninstall
   generated/man/datalad-unlock

Metadata handling
=================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-search
   generated/man/datalad-metadata
   generated/man/datalad-aggregate-metadata
   generated/man/datalad-extract-metadata

Reproducible execution
======================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-run
   generated/man/datalad-rerun
   generated/man/datalad-run-procedure

Miscellaneous commands
======================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-add-archive-content
   generated/man/datalad-clean
   generated/man/datalad-download-url
   generated/man/datalad-ls
   generated/man/datalad-test


Plugin commands
===============

.. toctree::
   :maxdepth: 1

   generated/man/datalad-add-readme
   generated/man/datalad-addurls
   generated/man/datalad-check-dates
   generated/man/datalad-export-archive
   generated/man/datalad-export-to-figshare
   generated/man/datalad-no-annex
   generated/man/datalad-wtf

Plumbing commands
=================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-annotate-paths
   generated/man/datalad-clone
   generated/man/datalad-create-test-dataset
   generated/man/datalad-diff
   generated/man/datalad-sshrun
   generated/man/datalad-siblings
   generated/man/datalad-subdatasets

Commands of the future
======================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-rev-run
   generated/man/datalad-rev-save
   generated/man/datalad-status
